﻿(function(Speak) {

    require.config({
        paths: {
            itemService: "/sitecore/shell/client/Services/Assets/lib/itemservice.min",
            stagingConstants: "/sitecore/shell/client/Applications/Publishing/StagingConstants"
        }
    });

    Speak.pageCode(["publishingUtils", "publishingConstants", "publishingShared", "itemService", "stagingConstants"], function (Utils, Constants, Shared, ItemService, StagingConstants) {
        return {
            stagingMessages: null,

            initialize: function () {
                var dialog = this;

                $.ajax({
                    url: StagingConstants.urls.getStagingMessages,
                    method: "GET",
                    contentType: "application/json",
                    dataType: "json"
                })
                .done(function (response) {
                    dialog.stagingMessages = response.Messages;
                    dialog.GenericDataSourceIdleProjects.loadData();
                    dialog.GenericDataSourceRunningProjects.loadData();
                })
                .fail(function (jqXHR) {
                    if (jqXHR.status === 401) {
                        window.top.location.href = StagingConstants.urls.loginPage;
                    }
                });
            },

            initialized: function () {
                this.GenericDataSourceIdleProjects.on("change:DynamicData", $.proxy(this.onIdleProjectsLoaded, this));
                this.GenericDataSourceRunningProjects.on("change:DynamicData", $.proxy(this.onRunningProjectsLoaded, this));
                this.ListControlIdleProjects.on("change:CheckedValues", $.proxy(this.onProjectSelectionChange, this));
                this.HyperlinkButtonRefreshProjects.on("click", $.proxy(this.onRefreshClicked, this));
                this.HyperlinkButtonStartStaging.on("click", $.proxy(this.startStagingProjects, this));
            },

            render: function() {
            },

            onIdleProjectsLoaded: function () {
                if (!this.GenericDataSourceIdleProjects.DynamicData.Succeeded) {
                    var message = this.stagingMessages[StagingConstants.messageKeys.stagingErrorIdleProjects];
                    this.parent.MessageBar.add(message);
                }
            },

            onRunningProjectsLoaded: function() {
                if (!this.GenericDataSourceRunningProjects.DynamicData.Succeeded) {
                    var message = this.stagingMessages[StagingConstants.messageKeys.stagingErrorRunningProjects];
                    this.parent.MessageBar.add(message);
                }
            },

            onProjectSelectionChange: function (values) {
                this.HyperlinkButtonStartStaging.IsEnabled = (values.length > 0);
            },

            onRefreshClicked: function () {
                this.parent.MessageBar.reset();
                this.ListControlIdleProjects.reset();
                this.ListControlRunningProjects.reset();
                this.GenericDataSourceIdleProjects.loadData();
                this.GenericDataSourceRunningProjects.loadData();
            },

            startStagingProjects: function () {
                var dialog = this;
                var message = "";

                var checkedItems = this.ListControlIdleProjects.CheckedValues;
                if (checkedItems.length > 0) {
                    var newStagingJob = {
                        "Projects": checkedItems
                    };

                    $.ajax({
                        url: StagingConstants.urls.startStagingProjects,
                        method: "POST",
                        contentType: "application/json",
                        dataType: "json",
                        data: JSON.stringify(newStagingJob)
                    })
                    .done(function (response) {
                        if (response.Succeeded) {
                            message = dialog.stagingMessages[StagingConstants.messageKeys.stagingProjectsStarted];
                            dialog.parent.MessageBar.reset([message]);
                            dialog.ListControlIdleProjects.reset();
                            dialog.ListControlRunningProjects.reset();
                            dialog.GenericDataSourceIdleProjects.loadData();
                            dialog.GenericDataSourceRunningProjects.loadData();

                            var closeMessage = dialog.stagingMessages[StagingConstants.messageKeys.stagingClose];
                            dialog.parent.ButtonCancel.Text = closeMessage.Text;
                        } else {
                            message = dialog.stagingMessages[StagingConstants.messageKeys.stagingError];
                            dialog.parent.MessageBar.reset([message]);
                        }
                    })
                    .fail(function (jqXHR) {
                        if (jqXHR.status === 401) {
                            window.top.location.href = StagingConstants.urls.loginPage;
                        } else {
                            message = dialog.stagingMessages[StagingConstants.messageKeys.stagingError];
                            dialog.parent.MessageBar.reset([message]);
                        }
                    });
                }
            }
        };
    }, "StagingApp");

})(Sitecore.Speak);